@@ -3,6 +3,9 @@ package AtteanX::Model::SPARQL;
 use v5.14;
 use warnings;
 
+our $AUTHORITY = 'cpan:KJETILK';
+our $VERSION   = '0.012';
+
 use Moo;
 use Types::Standard qw(InstanceOf);
 use namespace::clean;
@@ -15,7 +18,8 @@ has 'store'    => (
 										  get_quads => 'get_triples',
 										  count_quads => 'count_triples',
 										  get_sparql => 'get_sparql',
-										  plans_for_algebra => 'plans_for_algebra'
+										  plans_for_algebra => 'plans_for_algebra',
+										  count_quads_estimate => 'count_quads_estimate'
 										}
 						);
 
